@@ -62,6 +62,7 @@ static int parse_get_line(FILE *f, char **s, int *length)
       if (i == *length - 1){
 	*length *= 2;
 	*s = (char *)realloc(*s, *length + 1);
+//        memset(s + *length/2, 0, (*length - *length/2) + 1);
       }
       /* check for continuation lines */
       if(i > 0 && c == '\n' && (*s)[i-1] == '\\'){
@@ -174,7 +175,7 @@ int parse_input_block(FILE *f, char **s, int *length, parse_result *pc) {
                 str_trim(tok2);
 
                 col = rec->value.block->lines[l].n;
-                char *mtxel = (char *) malloc(strlen(tok2) + strlen(rec->name) + 20);
+                char *mtxel = (char *) calloc(strlen(tok2) + strlen(rec->name) + 20, sizeof(*mtxel));
                 assert(mtxel);
                 sprintf(mtxel, "%s[%i][%i] = %s", rec->name, l, col, tok2);
                 parse_exp(mtxel, pc);
@@ -240,9 +241,9 @@ int parse_file_stream(FILE *f, const int set_used) {
 
     // initial_length is just a starter length, not the maximum
     length = initial_length;
-    s = (char *) malloc(length + 1);
+    s = (char *) calloc(length + 1, sizeof(*s));
     if (!s) {
-        error_return(-1, "malloc failed to allocate initial length for line char");
+        error_return(-1, "calloc failed to allocate initial length for line char");
     }
 
     // Parse the file once, for RandomSeed
@@ -335,7 +336,7 @@ void parse_environment(const char* prefix)
   char* flag;
   parse_result pc;
 
-  flag = (char *)malloc(strlen(prefix) + 11);
+  flag = (char *)calloc(strlen(prefix) + 11, sizeof(*flag));
   strcpy(flag, prefix);
   strcat(flag, "PARSE_ENV");
   
@@ -365,7 +366,7 @@ void parse_environment(const char* prefix)
 
 char* get_mtxel_name(const char* block, int l, int col)
 {
-  char *mtxel = (char *)malloc(strlen(block) + 20);
+  char *mtxel = (char *)calloc(strlen(block) + 20, sizeof(*mtxel));
   sprintf(mtxel, "%s[%i][%i]", block, l, col);
   return mtxel;
 }
@@ -489,13 +490,13 @@ char *parse_string(const char *name, char *def)
       fprintf(stderr, "Parser error: expecting a string for variable '%s'.\n", name);
       exit(1);
     }
-    ret = (char *)malloc(strlen(ptr->value.str) + 1);
+    ret = (char *)calloc(strlen(ptr->value.str) + 1, sizeof(*ret));
     strcpy(ret, ptr->value.str);
     if(!disable_write) {
       fprintf(fout, "%s = \"%s\"\n", name, ret);
     }
   }else{
-    ret = (char *)malloc(strlen(def) + 1);
+    ret = (char *)calloc(strlen(def) + 1, sizeof(*ret));
     strcpy(ret, def);
     if(!disable_write) {
       fprintf(fout, "%s = \"%s\"\t\t# default\n", name, ret);
@@ -511,7 +512,7 @@ int parse_block (const char *name, sym_block **blk)
   ptr = getsym(name);
   if(ptr && ptr->type == S_BLOCK){
     *blk = ptr->value.block;
-    (*blk)->name = (char *)malloc(strlen(name) + 1);
+    (*blk)->name = (char *)calloc(strlen(name) + 1, sizeof(*((*blk)->name)));
     strcpy((*blk)->name, name);
     if(!disable_write) {
       fprintf(fout, "Opened block '%s'\n", name);
